@@ -1,21 +1,19 @@
 #!/usr/bin/env python
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
 # vim: fileencoding=UTF-8 filetype=python ff=unix et ts=4 sw=4 sts=4 tw=120
 # author: Christer Sjöholm -- hcs AT furuvik DOT net
 
 
 import argparse
 import datetime
+import importlib.metadata
 import locale
 import logging
 import pathlib
 import json
 import sys
 
-import oauth2client.client
-import oauth2client.file
-import oauth2client.tools
-import pkg_resources
+from google_auth_oauthlib import flow
 
 import goobook.config
 from goobook.goobook import GooBook, Cache, GoogleContacts, parse_groups, parse_contacts
@@ -23,26 +21,22 @@ from goobook.storage import unstorageify
 
 log = logging.getLogger(__name__)  # pylint: disable=invalid-name
 
-SCOPES = 'https://www.google.com/m8/feeds'  # read/write access to Contacts and Contact Groups
+SCOPES = 'https://www.googleapis.com/auth/contacts'  # read/write access to Contacts and Contact Groups
 
 AUTHENTICATE_HELP_STRING = '''Google OAuth authentication.
 
-Before running goobook authenticate you need a client_id and a client_secret, get it like this:
+Before running goobook authenticate you need a client secrets JSON file, get it like this:
 
 Go to https://developers.google.com/people/quickstart/python
 and click "Enable the People API"
 select a name (ex. GooBook)
 select desktop application
-save the client_id and client_secret to be used below::
+click "download JSON" to be used below
 
-    $ goobook authenticate -- CLIENT_ID CLIENT_SECRET
+    $ goobook authenticate -- client_secrets.json
 
 and follow the instructions.
 
-if it doesn't open a webbrowser use
-
-goobook authenticate --noauth_local_webserver -- CLIENT_ID CLIENT_SECRET
-
 If you get the page "This app isn't verified" select Advanced and the "Go to GooBook (unsafe)" at the bottom.
 '''
 
@@ -56,7 +50,7 @@ def main():
                         const=logging.INFO, help='Be verbose about what is going on (stderr).')
     parser.add_argument('-V', '--version',
                         action='version',
-                        version='%%(prog)s %s' % pkg_resources.get_distribution("goobook").version,
+                        version='%%(prog)s %s' % importlib.metadata.version("goobook"),
                         help="Print version and exit")
     parser.add_argument('-d', '--debug', dest="log_level", action='store_const',
                         const=logging.DEBUG, help='Output debug info (stderr).')
@@ -108,12 +102,9 @@ def main():
 
     parser_auth = subparsers.add_parser('authenticate',
                                         description=AUTHENTICATE_HELP_STRING,
-                                        formatter_class=argparse.RawDescriptionHelpFormatter,
-                                        parents=[oauth2client.tools.argparser])
-    parser_auth.add_argument('client_id', metavar='CLIENT_ID',
-                             help='Client ID')
-    parser_auth.add_argument('client_secret', metavar='CLIENT_SECRET',
-                             help='Client secret')
+                                        formatter_class=argparse.RawDescriptionHelpFormatter)
+    parser_auth.add_argument('client_secrets_json', metavar='CLIENT_SECRETS_JSON',
+                             help='Client secrets JSON file')
     parser_auth.set_defaults(func=do_authenticate)
 
     parser_unauth = subparsers.add_parser('unauthenticate',
@@ -136,6 +127,9 @@ def main():
     except goobook.config.ConfigError as err:
         sys.exit('Configuration error: ' + str(err))
 
+    if config:
+        goobook.config.maybe_save_creds(config)
+
 ##############################################################################
 # sub commands
 
@@ -195,12 +189,11 @@ def do_reload(config, _args):
 
 
 def do_authenticate(config, args):
-    store = config.store
     creds = config.creds
 
-    if not creds or creds.invalid:
-        flow = oauth2client.client.OAuth2WebServerFlow(args.client_id, args.client_secret, SCOPES)
-        creds = oauth2client.tools.run_flow(flow, store, args)
+    if not creds:
+        f = flow.InstalledAppFlow.from_client_secrets_file(args.client_secrets_json, SCOPES)
+        config.creds = f.run_local_server()
     else:
         print('You are already authenticated.')
 
@@ -210,6 +203,7 @@ def do_unauthenticate(config, _args):
     if oauth_db.exists():
         oauth_db.unlink()
         print("deleted", oauth_db)
+    config.creds = None
 
 
 if __name__ == '__main__':
